#########################
The PyGYRE Python Package
#########################

.. image:: https://img.shields.io/github/license/rhdtownsend/pygyre
   :alt: GitHub
   :target: https://github.com/rhdtownsend/pygyre/blob/main/COPYING
.. image:: https://img.shields.io/github/v/release/rhdtownsend/pygyre
   :alt: GitHub release (latest by date)
   :target: https://github.com/rhdtownsend/pygyre/releases/latest
.. image:: https://img.shields.io/github/issues/rhdtownsend/pygyre
   :alt: GitHub issues
   :target: https://github.com/rhdtownsend/pygyre/issues
.. image:: https://img.shields.io/readthedocs/pygyre
   :alt: Read the Docs
   :target: https://pygyre.readthedocs.io/en/stable

Overview
========
	    
PyGYRE is a Python package that provides support for the `GYRE stellar
oscillation code <https://github.com/rhdtownsend/gyre>`__.

Documentation
=============

Full documentation for PyGYRE, including installation instructions,
can be found at https://pygyre.readthedocs.io/en/stable.
